function [p,c] = simplex_mt(f,mult,period,inits,show,epsilon)

% Szimplex mdszer megvalstsa plusok kzeltsre.
% paramterek:
%   - kzeltend jel (sorvektor)
%   - plusok szma (pl. 3, 4)
%   - kezdszimplex (pl. [-1 0 0 1 0 -1] - sorvektor: 2*polenum)
%   - plusok multiplicitsa (pl. 2, 3)
%   - rajzoljon-e kzben (logikai)


% kezdszimplex

polenum = length(mult); % plusok szma
n = 2*polenum; % dimenzi
ne = n + 1; % szimplex cscsainak szma

% szimplex:
% cscs1koord1 cscs1koord2 ... cscs1koordn fggvnyrtk1
% cscs2koord2 cscs2koord2 ... cscs2koordn fggvnyrtk2
% ...
% cscsne ...                                fggvnyrtkne

simplex = zeros(ne,ne);
h = .1;
simplex(1,:) = [inits 0];
he          = h * ones(1,1+polenum*2);
for j = 2:ne
    simplex(j,:) = simplex(1,:);
    simplex(j,j-1) = simplex(j,j-1) + he(j-1);
end

alfa = 1; % tkrzsi paramter
beta = 0.5; % zsugortsi paramter
gamma = 2; % nyjtsi paramter
if nargin<6
    epsilon=1e-6;
end
% stepkorlat = 100; % korlt a lpsek szmra

% rajzolshoz

styles = ['bo'; 'bx'; 'b.'; 'bd'];


% -------------------------------------------------------------------------



% a kzeltend fggvny

f = addimag(f);

% a kzeltend jel

sample = size(f,2);

t = linspace(0,2*pi,sample+1);
t = t(1:sample);
unit_disc = exp(1i*t);


% kezdsimplexex fggvnyrtkei

for j = 1:ne
    [c,simplex(j,ne)] = mt_coeffs(f,periodize_poles(multiply_poles(coords2params(simplex(j,1:n)),mult),period)); % fggvnyrtk az eltrs
end

% iterci

step = 0;
while std(simplex(:,ne)) > epsilon
    step = step + 1;
    
	% rendezs
	simplex = sortrows(simplex,ne);
	
	% slypont
	xs = sum(simplex(1:n,1:n)) / n;
	
	% tkrztt pont
	xr = (1 + alfa) * xs - alfa * simplex(n+1,1:n);
	[c,fvxr] = mt_coeffs(f,periodize_poles(multiply_poles(coords2params(xr),mult),period)); % fvxr
	
	% hrom eset van
	
	if fvxr < simplex(1,ne) % 1. legjobb fggvnyrtk    
        % megvizsgljuk a nyjtott pontot, jobb-e
        xe = gamma * xr + (1 - gamma) * xs;
        [c,fvxe] = mt_coeffs(f,periodize_poles(multiply_poles(coords2params(xe),mult),period)); % fvxe
        
        if fvxe < fvxr
            simplex(ne,:) = [xe,fvxe];
        else
            simplex(ne,:) = [xr,fvxr];
        end
	end
	
	if fvxr >= simplex(1,ne) && fvxr <= simplex(n,ne) % 2. kzepes fggvnyrtk
        simplex(ne,:) = [xr,fvxr];
	end
	
	if fvxr > simplex(n,ne)
        % megvizsgljuk a zsugortott pontot (a megfelelt), jobb-e
        if fvxr >= simplex(ne,ne)
            xc = beta * simplex(ne,1:n) + (1 - beta) * xs;
        else
            xc = beta * xr + (1 - beta) * xs;
        end
        [c,fvxc] = mt_coeffs(f,periodize_poles(multiply_poles(coords2params(xc),mult),period)); % fvxc
        
        if fvxc < fvxr && fvxc < simplex(ne,ne)
            simplex(ne,:) = [xc,fvxc];
        else
            for k = 2:ne
                simplex(k,1:n) = (simplex(k,1:n) + simplex(1,1:n))/2;
                [c,simplex(k,ne)] = mt_coeffs(f,periodize_poles(multiply_poles(coords2params(simplex(k,1:n)),mult),period));
            end
        end
	end
	
    % rajz
    
    if show
    
        subplot(1,2,1);
        sz = coords2params_all(simplex(:,1:n));
        [c,e] = mt_coeffs(f,periodize_poles(multiply_poles(coords2params(simplex(1,1:n)),mult),period));
        fs = mt_generate(sample,periodize_poles(multiply_poles(coords2params(simplex(1,1:n)),mult),period),c);
	
        plot(unit_disc,'k');
        title(['step: ' int2str(step)]);
        hold on;
        for k = 1:polenum
            plot(sz(:,k),styles(k,:));
        end
        % plot(c,'rd');
        % plot(poles,'rd');
		hold off;
        
        subplot(1,2,2);
		plot(t,zeros(1,sample),'k');
		hold on;
        plot(t,real(f),'r');
		% plot(t,real(f),'m',t,imag(f),'c');
		plot(t,real(fs),'b');
        % plot(t,real(fs),'r',t,imag(fs),'b');
		% plot(t,real(fs-f),'g',t,imag(fs-f),'g:');
		hold off;
        
	
        if step == 1
            pause
        end
        if rem(step,10) == 0
            pause(0.01);
        end
        pause(0.01);
    end
    
end


% s a vgeredmny:

simplex = sortrows(simplex,ne);
p = coords2params(simplex(1,1:n));
[c,e] = mt_coeffs(f,periodize_poles(multiply_poles(p,mult),period));


