% G_CLASS_FUSION - Bayesian fusion of classification results.
% 
% Performs a Bayesian fusion for two classification results.
% 
% Copyright (C) 2018 ELTE IK NumAnal, GNU GPL 3

function [classes_fused, accuracy_fused, mat_fused, prob_est_fused] = g_class_fusion(prob_est1, prob_est2, class_map, test_classes, mat_size)
    % Bayesian prob estimates
    prob_est_fused = prob_est1 .* prob_est2;
    prob_est_fused = prob_est_fused ./ (sum(prob_est_fused, 2)*ones(1, size(prob_est_fused, 2)));
    % fused classes
    [~, classes_fused] = max(prob_est_fused, [], 2);
    classes_fused = class_map(classes_fused);
    % confusion matrix & accuracy
    [accuracy_fused, mat_fused] = g_class_mat(classes_fused, test_classes, mat_size);
end
