% G_CLASS_REJECTION - Rejection fusion of classification results.
% 
% Performs a rejection fusion for two classification results.
% 
% Copyright (C) 2018 ELTE IK NumAnal, GNU GPL 3

function [accuracy_rejection, mat_rejection, p_rejection] = g_class_rejection(classes1, classes2, test_classes, prob_est_fused, err, mat_size)
    % reject different or below error rate
    classes_same = classes1 == classes2;
    classes_q = max(prob_est_fused, [], 2) > 1-err & classes_same(:);
    % fused/rejected classes
    test_classes_r = test_classes(classes_q);
    classes_r = classes1(classes_q);
    % confusion matrix & accuracy
    [accuracy_rejection, mat_rejection] = g_class_mat(classes_r, test_classes_r, mat_size);
    p_rejection = 100 - sum(classes_q) / length(test_classes) * 100;
end
