% G_FEAT_MTS - Rational (Malmquist-Takenaka) projection.
% 
% Calculates the coeffients of the MT projection of the heartbeats using the
% given inverse pole combination (poles with multiplicities).
% 
% Copyright (C) 2018 ELTE IK NumAnal, GNU GPL 3

function [mts_feat, err, appr] = g_feat_rat_mts(samples, poles, pole_mult)
    n = size(samples, 2);
    mpoles = multiply_poles(poles, pole_mult);
    mts = mt_system(n, [0 mpoles]);
    mts_re = real(mts);
    mts_im = imag(mts);
    
    co_re = 2 * samples * mts_re' / n;
    co_im = 2 * samples * mts_im' / n;
    co_re(:, 1) = co_re(:, 1) / 2;
    co_im(:, 1) = co_im(:, 1) / 2;
    
    mts_feat = [co_re(:, 2:end) co_im(:, 2:end)];
    
    appr = co_re * mts_re + co_im * mts_im;
    err = sum(sqrt(sum((samples - appr).^2, 2)));
end
