% G_SEGMENT_BEATS - Heartbeat segmentation.
% 
% Segment the heartbeats of a record using the database annotations.
%
% Copyright (C) 2018 ELTE IK NumAnal, GNU GPL 3

function [samples, beatmask] = g_segment_beats(signal, loc, pre_samples, post_samples, adaptive)
    [n, leads] = size(signal);
    n_samples = pre_samples + post_samples;
    
    beatmask = (loc > pre_samples) & (loc <= n-post_samples);
    loc = loc(beatmask);
    dloc = diff([-n_samples loc max(loc)+n_samples]);

    samples = zeros(length(loc), n_samples, leads);
    for i = 1:length(loc)
        l = loc(i);
        if adaptive
            l0 = dloc(i);
            pre = min(min(round(pre_samples * l0 / n_samples), l), pre_samples);
            s1 = signal(l-pre+1:l, :);
            if pre < pre_samples
                s1 = [zeros(pre_samples-pre, leads); s1];
            end
            l1 = dloc(i+1);
            post = min(min(round(post_samples * l1 / n_samples), n-l), post_samples);
            s2 = signal(l+1:l+post, :);
            if post < post_samples
                s2 = [s2; zeros(post_samples-post, leads)];
            end
            s = [s1; s2];
        else
            s = signal(l-pre_samples+1:l+post_samples, :);
        end
        samples(i,:,:) = s;
    end
end
